Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1928)

Unified Diff: chrome/browser/ui/views/frame/glass_browser_frame_view.h

Issue 1392193004: Miscellaneous cleanup. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Fix bad merge Created 5 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/ui/views/frame/glass_browser_frame_view.h
diff --git a/chrome/browser/ui/views/frame/glass_browser_frame_view.h b/chrome/browser/ui/views/frame/glass_browser_frame_view.h
index 748ef25c38f03f1d82e55f668a8f306120c86f38..21871be62ccd0e3aeabbb97369ce771e28f536ee 100644
--- a/chrome/browser/ui/views/frame/glass_browser_frame_view.h
+++ b/chrome/browser/ui/views/frame/glass_browser_frame_view.h
@@ -73,7 +73,7 @@ class GlassBrowserFrameView : public BrowserNonClientFrameView,
void PaintRestoredClientEdge(gfx::Canvas* canvas);
// Layout various sub-components of this view.
- void LayoutAvatar();
+ void LayoutIncognitoIcon();
void LayoutNewStyleAvatar();
void LayoutClientView();
@@ -90,8 +90,8 @@ class GlassBrowserFrameView : public BrowserNonClientFrameView,
// Displays the next throbber frame.
void DisplayNextThrobberFrame();
- // The layout rect of the avatar icon, if visible.
- gfx::Rect avatar_bounds_;
+ // The layout rect of the incognito icon, if visible.
+ gfx::Rect incognito_bounds_;
// The bounds of the ClientView.
gfx::Rect client_view_bounds_;
« no previous file with comments | « no previous file | chrome/browser/ui/views/frame/glass_browser_frame_view.cc » ('j') | chrome/browser/ui/views/tabs/tab.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698